summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmditaskbar.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmditaskbar.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
index 2de377cb..e4ec2f8b 100644
--- a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
+++ b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
@@ -88,7 +88,7 @@ signals:
*/
void rightMouseButtonClicked( KMdiChildView* );
/**
* Emitted when the button text has changed. Internally connected with KMdiTaskBar::tqlayoutTaskBar
*/
void buttonTextChanged( int );
public slots:
@@ -173,7 +173,7 @@ public:
};
protected:
/**
* Reimplemented from its base class to call tqlayoutTaskBar, additionally.
*/
void resizeEvent( TQResizeEvent* );
protected slots:
@@ -184,7 +184,7 @@ protected slots:
* fixed width and show() is called for each one.
* If one drags the taskbar to a vertical orientation, the button width is set to 80 pixel.
*/
- void tqlayoutTaskBar( int taskBarWidth = 0 );
+ void layoutTaskBar( int taskBarWidth = 0 );
public slots:
/**
* Pushes the desired taskbar button down (switch on), the old one is released (switched off).
@@ -88,7 +88,7 @@ signals:
void rightMouseButtonClicked( KMdiChildView* );
/**
- * Emitted when the button text has changed. Internally connected with KMdiTaskBar::tqlayoutTaskBar
+ * Emitted when the button text has changed. Internally connected with KMdiTaskBar::layoutTaskBar
*/
void buttonTextChanged( int );
@@ -173,7 +173,7 @@ public:
protected:
/**
- * Reimplemented from its base class to call tqlayoutTaskBar, additionally.
+ * Reimplemented from its base class to call layoutTaskBar, additionally.
*/
void resizeEvent( TQResizeEvent* );